@@ -12,7 +12,7 @@
 #
 ##############################################################################
 
-from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile
+from zope.browserpage.viewpagetemplatefile import ViewPageTemplateFile
 from z3c.optionstorage.interfaces import IOptionStorage
 from z3c.optionstorage import OptionDict
 
